==> kjy-center-api-0.8.13-ctc6-20200402.015616-2-sources.jar: cn/com/duiba/kjy/api/dto/explosionContent/ExplosionContentDto.java <==
package cn.com.duiba.kjy.api.dto.explosionContent;

import java.io.Serializable;
import java.util.Date;

import cn.com.duiba.kjy.api.enums.accurate.TagTypeEnum;
import lombok.Data;

/**
 * 爆款素材文章表
 * @author kjj mybatis generator 
 * 2020-01-06
 */
@Data
public class ExplosionContentDto implements Serializable {


    private static final long serialVersionUID = -4119512983545734586L;

    /**
     *
     *主键ID
     * not null default = null
     */
    private Long id;

    /**
     *
     *tb_content主键ID
     */
    private Long contentId;

    /**
     *
     *tb_admin_article_collection主键ID
     */
    private Long articleCollectionId;

    /**
     *
     *精准素材类型 0:默认素材 1:爆款素材 2:必转素材
     * @see cn.com.duiba.kjy.api.enums.MaterialTypeEnum
     */
    private Integer explosionContentType;

    /**
     * 保险分类
     * @see TagTypeEnum
     */
    private Long classify;

    /**
     *
     *文章内标签，最多三个标签，每个标签不超过6个字，标签之间用英文逗号隔开
     * max length = 255
     * not null default = 
     */
    private String tags;

    /**
     *
     *推荐理由
     * max length = 255
     * not null default = 
     */
    private String recommendReason;

    /**
     *
     *自定义标签
     */
    private String customTag;

    /**
     *
     *发布时间
     */
    private Date releaseTime;

    /**
     *
     *内容状态:0:不可用 1:可用
     * @see cn.com.duiba.kjy.api.enums.accurate.AccurateContentStatusEnum
     * not null default = 0
     */
    private Integer contentStatus;

    /**
     *
     *险种属性标签id，对应tb_accurate_tag的主键id
     */
    private Long insurancePropertyTag;

    /**
     *
     *转发量
     * not null default = 0
     */
    private Integer shareNum;

    /**
     *
     *是否删除，1=已删除
     * not null default = 0
     */
    private Integer deleted;

    /**
     *
     *创建时间
     * not null default = CURRENT_TIMESTAMP
     */
    private Date gmtCreate;

    /**
     *
     *素材标题
     */
    private String title;

    /**
     *
     *素材oss
     */
    private String img;
}

==> kjy-center-api-0.9.32-ctc2-20200810.023644-1-sources.jar: cn/com/duiba/kjy/api/dto/explosionContent/ExplosionContentDto.java <==
package cn.com.duiba.kjy.api.dto.explosionContent;

import cn.com.duiba.kjy.api.enums.accurate.TagTypeEnum;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 爆款素材文章表
 * @author kjj mybatis generator 
 * 2020-01-06
 */
@Data
public class ExplosionContentDto implements Serializable {


    private static final long serialVersionUID = -4119512983545734586L;

    /**
     *
     *主键ID
     * not null default = null
     */
    private Long id;

    /**
     *
     *tb_content主键ID
     */
    private Long contentId;

    /**
     *
     *tb_admin_article_collection主键ID
     */
    private Long articleCollectionId;

    /**
     *
     *精准素材类型 0:默认素材 1:爆款素材 2:必转素材
     * @see cn.com.duiba.kjy.api.enums.MaterialTypeEnum
     */
    private Integer explosionContentType;

    /**
     * 保险分类
     * @see TagTypeEnum
     */
    private Long classify;

    /**
     *
     *文章内标签，最多三个标签，每个标签不超过6个字，标签之间用英文逗号隔开
     * max length = 255
     * not null default = 
     */
    private String tags;

    /**
     *
     *推荐理由
     * max length = 255
     * not null default = 
     */

    /**
     *
     *自定义标签
     */
    private String customTag;

    /**
     *
     *发布时间
     */
    private Date releaseTime;

    /**
     *
     *内容状态:0:不可用 1:可用
     * @see cn.com.duiba.kjy.api.enums.accurate.AccurateContentStatusEnum
     * not null default = 0
     */
    private Integer contentStatus;

    /**
     *
     *险种属性标签id，对应tb_accurate_tag的主键id
     */
    private Long insurancePropertyTag;

    /**
     *
     *转发量
     * not null default = 0
     */
    private Integer shareNum;

    /**
     *
     *是否删除，1=已删除
     * not null default = 0
     */
    private Integer deleted;

    /**
     *
     *创建时间
     * not null default = CURRENT_TIMESTAMP
     */
    private Date gmtCreate;

    /**
     *
     *素材标题
     */
    private String title;

    /**
     *
     *素材oss
     */
    private String img;

    /**
     * 是否为热文
     * @see cn.com.duiba.kjy.api.enums.explosioncontent.HotContentIsOrNotEnum
     */
    private Integer isHotContent;
}
